==> iohub-sdk-client-1.0-20250829.072845-126-sources.jar: com/ovopark/iohub/sdk/client/Client2ControlTransport.java <==
package com.ovopark.iohub.sdk.client;

import com.ovopark.iohub.sdk.model.PreFlowErrorRequest;
import com.ovopark.iohub.sdk.model.PreFlowErrorResponse;
import com.ovopark.iohub.sdk.model.TaskLockRequest;
import com.ovopark.iohub.sdk.model.TaskLockResponse;
import com.ovopark.iohub.sdk.model.instream.ReadJobAssignWorkRequest;
import com.ovopark.iohub.sdk.model.instream.ReadJobAssignWorkResponse;
import com.ovopark.iohub.sdk.model.instream.ReadJobStartRequest;
import com.ovopark.iohub.sdk.model.instream.ReadJobStartResponse;
import com.ovopark.iohub.sdk.model.outstream.RenderJobAssignWorkRequest;
import com.ovopark.iohub.sdk.model.outstream.RenderJobAssignWorkResponse;
import com.ovopark.iohub.sdk.model.outstream.RenderJobStartRequest;
import com.ovopark.iohub.sdk.model.outstream.RenderJobStartResponse;
import com.ovopark.kernel.shared.vclient.Client2ServerTransport;

public interface Client2ControlTransport extends ControlTransport , Client2ServerTransport {

    TaskLockResponse lockClient(TaskLockRequest taskLockRequest);

    PreFlowErrorResponse preFlowError(PreFlowErrorRequest preFlowErrorRequest);


    RenderJobStartResponse startRenderJob(RenderJobStartRequest renderJobStartRequest);

    RenderJobAssignWorkResponse assignWorkRenderJob(RenderJobAssignWorkRequest renderJobAssignWorkRequest);

    ReadJobStartResponse startReadJob(ReadJobStartRequest readJobStartRequest);

    ReadJobAssignWorkResponse assignWorkReadJob(ReadJobAssignWorkRequest readJobAssignWorkRequest);


}

==> iohub-sdk-client-1.0-20251215.070211-152-sources.jar: com/ovopark/iohub/sdk/client/Client2ControlTransport.java <==
package com.ovopark.iohub.sdk.client;

import com.ovopark.iohub.sdk.model.PreFlowErrorRequest;
import com.ovopark.iohub.sdk.model.PreFlowErrorResponse;
import com.ovopark.iohub.sdk.model.TaskLockRequest;
import com.ovopark.iohub.sdk.model.TaskLockResponse;
import com.ovopark.iohub.sdk.model.instream.ReadJobAssignWorkRequest;
import com.ovopark.iohub.sdk.model.instream.ReadJobAssignWorkResponse;
import com.ovopark.iohub.sdk.model.instream.ReadJobStartRequest;
import com.ovopark.iohub.sdk.model.instream.ReadJobStartResponse;
import com.ovopark.iohub.sdk.model.outstream.RenderJobAssignWorkRequest;
import com.ovopark.iohub.sdk.model.outstream.RenderJobAssignWorkResponse;
import com.ovopark.iohub.sdk.model.outstream.RenderJobStartRequest;
import com.ovopark.iohub.sdk.model.outstream.RenderJobStartResponse;
import com.ovopark.iohub.sdk.model.proto.TaskCreatedRequest;
import com.ovopark.kernel.shared.vclient.Client2ServerTransport;
import com.ovopark.module.shared.BaseResult;

public interface Client2ControlTransport extends ControlTransport , Client2ServerTransport {

    TaskLockResponse lockClient(TaskLockRequest taskLockRequest);

    PreFlowErrorResponse preFlowError(PreFlowErrorRequest preFlowErrorRequest);


    RenderJobStartResponse startRenderJob(RenderJobStartRequest renderJobStartRequest);

    RenderJobAssignWorkResponse assignWorkRenderJob(RenderJobAssignWorkRequest renderJobAssignWorkRequest);

    ReadJobStartResponse startReadJob(ReadJobStartRequest readJobStartRequest);

    ReadJobAssignWorkResponse assignWorkReadJob(ReadJobAssignWorkRequest readJobAssignWorkRequest);

    BaseResult<?> watermarkSync(TaskCreatedRequest taskCreatedRequest);
}
